==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPAtomicAggregate.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPAtomicAggregate_cxx_Version = 
"$Id: TRIPAtomicAggregate.cxx,v 1.1 2000/11/02 02:10:49 surendra Exp $";

#include "TRIPAtomicAggregate.hxx"
#include "TRIPUtil.hxx"
#include "cpLog.h"


TRIPAtomicAggregate::TRIPAtomicAggregate(const TRIPAtomicAggregate& other) 
{
     copyObj(other);
}

TRIPAtomicAggregate& 
TRIPAtomicAggregate::operator=(const TRIPAtomicAggregate& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPAtomicAggregate::dump(ostream& os) const
{
    os.width(25);
    os << "**AtomicAggregate**" << endl;
}

void 
TRIPAtomicAggregate::writeData(int id) const throw(VNetworkException&)
{
    TRIPRouteAttr::writeData(id);
}

TRIPAtomicAggregate::TRIPAtomicAggregate(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPRouteAttr(buf)
{
    if(_hdr->getAttrType() != TRIP_ATOMIC_AGGREGATE)
    {
        cpLog(LOG_ALERT, "Bad Atomic Aggregate Attribute ");
        throw TRIPBadDataException("Bad Atomic Aggregate Attribute",
                                   __FILE__, __LINE__, 0);
    }
}

void 
TRIPAtomicAggregate::copyObj(const TRIPAtomicAggregate& other)
{
    TRIPRouteAttr::copyObj(other);
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPAtomicAggregate.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPAtomicAggregate_cxx_Version = 
"$Id: TRIPAtomicAggregate.cxx,v 1.5 2001/03/05 20:21:19 kevinmc Exp $";

#include "TRIPAtomicAggregate.hxx"
#include "TRIPUtil.hxx"
#include "TRIPErrorHandler.hxx"
#include "cpLog.h"


TRIPAtomicAggregate::TRIPAtomicAggregate(const TRIPAtomicAggregate& other) 
{
     copyObj(other);
}

TRIPAtomicAggregate& 
TRIPAtomicAggregate::operator=(const TRIPAtomicAggregate& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPAtomicAggregate::dump(ostream& os) const
{
    os.width(25);
    os << "**AtomicAggregate**" << endl;
}

void 
TRIPAtomicAggregate::writeData(int id) const throw(VNetworkException&)
{
    TRIPRouteAttr::writeData(id);
}

TRIPAtomicAggregate::TRIPAtomicAggregate(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPRouteAttr(buf)
{
    if(_hdr->getAttrType() != TRIP_ATOMIC_AGGREGATE)
    {
        throw TRIPBadDataException("Bad Atomic Aggregate Attribute",
                        __FILE__, __LINE__, TRIP_ERR_UPDATE, U_INVALID_ATTR);
    }
}

void 
TRIPAtomicAggregate::copyObj(const TRIPAtomicAggregate& other)
{
    TRIPRouteAttr::copyObj(other);
}

bool 
TRIPAtomicAggregate::isEqualAttribute(const TRIPRouteAttr& attr) const
{
    assert(attr.getType() == TRIP_ATOMIC_AGGREGATE);
    return(TRIPRouteAttr::isEqualAttribute(attr));
}
